@@ -116,8 +116,8 @@ void
 on_m_winemine_activate                (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (system("winemine -v >/dev/null 2>/dev/null")==NULL)
-  {
+  if (system("which winemine >/dev/null 2>/dev/null")==NULL)
+  {	  
     strcpy(Commande,"winemine ");      
     strcat(Commande," 2>>");
     strcat(Commande,FichierLog);
@@ -1445,7 +1445,7 @@ void
 on_m_regedit_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (system("regedit -v >/dev/null 2>/dev/null")==NULL)
+  if (system("which regedit >/dev/null 2>/dev/null")==NULL)
   {
     strcpy(Commande,"regedit ");      
     strcat(Commande," 2>>");
@@ -1466,7 +1466,7 @@ void
 on_m_progman_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (system("progman -v >/dev/null 2>/dev/null")==NULL)
+  if (system("which progman >/dev/null 2>/dev/null")==NULL)
   {
     strcpy(Commande,"progman ");      
     strcat(Commande," 2>>");
@@ -1487,7 +1487,7 @@ void
 on_m_uninst_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (system("uninstaller -v >/dev/null 2>/dev/null")==NULL)
+  if (system("which uninstaller >/dev/null 2>/dev/null")==NULL)
   {
     strcpy(Commande,"uninstaller ");      
     strcat(Commande," 2>>");
@@ -1508,7 +1508,7 @@ void
 on_m_notepad_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (system("notepad -v >/dev/null 2>/dev/null")==NULL)
+  if (system("which notepad >/dev/null 2>/dev/null")==NULL)
   {
     strcpy(Commande,"notepad ");      
     strcat(Commande," 2>>");
@@ -1529,7 +1529,7 @@ void
 on_m_cmd_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (system("wcmd -v >/dev/null 2>/dev/null")==NULL)
+  if (system("which wcmd >/dev/null 2>/dev/null")==NULL)
   {
     strcpy(Commande,"wcmd ");      
     strcat(Commande," 2>>");
@@ -1550,7 +1550,7 @@ void
 on_m_winhelp_activate                  (GtkMenuItem     *menuitem,
                                         gpointer         user_data)
 {
-  if (system("winhelp -v >/dev/null 2>/dev/null")==NULL)
+  if (system("which winhelp >/dev/null 2>/dev/null")==NULL)
   {
     strcpy(Commande,"winhelp "); 
     strcat(Commande," 2>>");
@@ -1564,4 +1564,4 @@ on_m_winhelp_activate                  (GtkMenuItem     *menuitem,
   {
     gtk_widget_show(ERR_APP_NOT_FOUND);
   }
-}
\ No newline at end of file
+}
